#!/bin/bash

#
# Copyright (c) 2007, Gregory Fleischer (gfleischer@gmail.com)
# 
# All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 
# 3. Neither the name of the author nor the names of its
#    contributors may be used to endorse or promote products derived from
#    this software without specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

parse_config_files()
{
    controlport=0
    sockshost=127.0.0.1
    socksport=9050
    privoxyhost=127.0.0.1
    privoxyport=8118

    torrc="/etc/tor/torrc"
    if [ -f "$torrc" ]; then

    # look for SocksPort [port]
	conf=`egrep '^[[:space:]]*SocksPort[[:space:]]+[[:digit:]]+[[:space:]]*#*.*$' $torrc | sed -e 's/^[^0-9]*\([0-9][0-9]*\).*$/\1/'`
	if [ -n "$conf" ]; then
	    socksport=$conf
	fi

    # look for SocksListenAddress [host]
	conf=`egrep '^[[:space:]]*SocksListenAddress[[:space:]]+[0-9.]+[[:space:]]*#*.*$' $torrc | sed -e 's/^[^0-9][^0-9]*\([0-9][0-9.]*\).*$/\1/'`
	if [ -n "$conf" ]; then
	    sockshost=$conf
	fi

    # look for SocksListenAddress [host]:[port]
	conf=`egrep '^[[:space:]]*SocksListenAddress[[:space:]]+[0-9.]+:[[:digit:]]+[[:space:]]*#*.*$' $torrc | sed -e 's/^[^0-9][^0-9]*\([0-9][0-9.]*\):.*$/\1/'`
	if [ -n "$conf" ]; then
	    sockshost=$conf
	fi

    # look for SocksListenAddress [host]:[port]
	conf=`egrep '^[[:space:]]*SocksListenAddress[[:space:]]+[0-9.]+:[[:digit:]]+[[:space:]]*#*.*$' $torrc | sed -e 's/^.*:\([0-9][0-9]*\).*$/\1/'`
	if [ -n "$conf" ]; then
	    socksport=$conf
	fi

    # look for ControlPort [port]
	conf=`egrep '^[[:space:]]*ControlPort[[:space:]]+[[:digit:]]+[[:space:]]*#*.*$' $torrc | sed -e 's/^[^0-9][^0-9]*\([0-9][0-9]*\).*$/\1/'`
	if [ -n "$conf" ]; then
	    controlport=$conf
	fi

    fi

    privoxyconfig="/etc/privoxy/config"
    if [ -f "$privoxyconfig" ]; then

	# listen-address ip:port
	conf=`egrep '^[[:space:]]*listen-address[[:space:]]+[0-9.]+:[[:digit:]]+[[:space:]]*#*.*$' $privoxyconfig | sed -e 's/^[^0-9][^0-9]*\([0-9][0-9.]*\):.*$/\1/'`
	if [ -n "$conf" ]; then
	    privoxyhost=$conf
	fi

	# listen-address ip:port
	conf=`egrep '^[[:space:]]*listen-address[[:space:]]+[0-9.]+:[[:digit:]]+[[:space:]]*#*.*$' $privoxyconfig | sed -e 's/^.*:\([0-9][0-9]*\).*$/\1/'`
	if [ -n "$conf" ]; then
	    privoxyport=$conf
	fi

	# listen-address :port
	conf=`egrep '^[[:space:]]*listen-address[[:space:]]+:[[:digit:]]+[[:space:]]*#*.*$' $privoxyconfig | sed -e 's/^.*:\([0-9][0-9]*\).*$/\1/'`
	if [ -n "$conf" ]; then
	    privoxyhost='*'
	    privoxyport=$conf
	fi

    fi

    if [ 1 = $dbg ]; then
	echo "SocksHost=$sockshost"
	echo "SocksPort=$socksport"
	echo "ControlPort=$controlport"
	echo "PrivoxyHost=$privoxyhost"
	echo "PrivoxyPort=$privoxyport"
    fi

}

